@@ -1752,7 +1752,7 @@ predict.ppmlasso = function(object, ..., newdata, interactions = NA)
   }
   if (object$family == "area.inter")
   {
-    if (is.na(interactions) == TRUE)
+    if (any(is.na(interactions)) == TRUE)
     {
       if (is.null(object$s.means) == FALSE)
       {
